Page 69 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 69

Home

    philosophy already expressed in the Declaration of
    Independence:

    We hold these Truths to be self-evident, that all Men
    are created equal, that they are endowed by their Creator
    with certain unalienable Rights, that among these are
    Life, Liberty, and the Pursuit of Happiness. That to
    secure these Rights, Governments are instituted among
    Men, deriving their just Powers from the Consent of the

    government been established upon the idea that man's
    rights came from God and that government's role was to
    protect those rights that had already been given him by
    his Creator. Furthermore, under this system, man could
    work out his own destiny. This was a total rejection of
    Old World Views of man and government. This was

    revolutionary!

    At this time in history most of the nations were ruled
    by a monarch. The Founding Fathers rejected this
    concept of government, and for good reason. Being
    students of and holding reverence for the Bible, they
    were familiar with the experience of the Jewish nation of
    Israel regarding a king. The Law of Moses made no
    provision for a king. The Israelites were to be ruled by
    God as responsible individuals, but they wanted to be
    like other nations, and have a king to rule over them. The
    Old Testament Scripture records that the leaders of Israel

    64

    The Secret Side of History

    The Constitution was the outcome of the basic

    Governed.

    Never before in the history of mankind had a